summaryrefslogtreecommitdiffstats
path: root/kpdf/shell/shell.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf/shell/shell.h')
-rw-r--r--kpdf/shell/shell.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpdf/shell/shell.h b/kpdf/shell/shell.h
index 298e1e2b..b6bbf499 100644
--- a/kpdf/shell/shell.h
+++ b/kpdf/shell/shell.h
@@ -59,14 +59,14 @@ namespace KPDF
* This method is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig*);
+ void saveProperties(TDEConfig*);
/**
* This method is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig*);
+ void readProperties(TDEConfig*);
void readSettings();
void writeSettings();
void setFullScreen( bool );
@@ -86,8 +86,8 @@ namespace KPDF
void delayedOpen();
signals:
- void restoreDocument(KConfig* config);
- void saveDocumentRestoreInfo(KConfig* config);
+ void restoreDocument(TDEConfig* config);
+ void saveDocumentRestoreInfo(TDEConfig* config);
private:
@@ -59,14 +59,14 @@ namespace KPDF
/**
- * This method is called when this app is restored. The KConfig
+ * This method is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties